pitchtools.NumberedObject
=========================

.. abjad-lineage:: abjad.tools.pitchtools.NumberedObject.NumberedObject.NumberedObject

.. autoclass:: abjad.tools.pitchtools.NumberedObject.NumberedObject.NumberedObject
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.NumberedObject.NumberedObject.NumberedObject.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.pitchtools.NumberedObject.NumberedObject.NumberedObject.__eq__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedObject.NumberedObject.NumberedObject.__ge__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedObject.NumberedObject.NumberedObject.__gt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedObject.NumberedObject.NumberedObject.__le__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedObject.NumberedObject.NumberedObject.__lt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedObject.NumberedObject.NumberedObject.__ne__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedObject.NumberedObject.NumberedObject.__repr__
   :noindex:
